"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var zipson_1 = require("zipson");
var ZipsonStreamWriter_1 = require("./ZipsonStreamWriter");
/**
 * Parse a stream of zipson data
 * Returns a promise that resolves with the parsed result
 */
function parseStream(stream) {
    return new Promise(function (resolve, reject) {
        var increment = zipson_1.parseIncremental();
        stream.on('error', reject);
        stream.on('end', function () {
            try {
                resolve(increment(null));
            }
            catch (e) {
                reject(e);
            }
        });
        stream.on('data', function (d) {
            try {
                increment(d.toString());
            }
            catch (e) {
                reject(e);
            }
        });
    });
}
exports.parseStream = parseStream;
/**
 * Stringify data to a stream of zipson output
 * Any errors during stringifying will be emitted as en error event on the stream.
 * Pass an optional bufferThreshold to set a minimum size of chunks written to the stream.
 * Returns the stream of zipson output
 */
function stringifyStream(data, options, bufferThreshold) {
    var writer = new ZipsonStreamWriter_1.ZipsonStreamWriter(bufferThreshold);
    // Defer stringify in order to return stream and proxy errors
    setTimeout(function () {
        try {
            zipson_1.stringifyTo(data, writer, options);
        }
        catch (e) {
            writer.stream.emit('error', e);
        }
    }, 0);
    return writer.stream;
}
exports.stringifyStream = stringifyStream;
//# sourceMappingURL=index.js.map